<?php

/**
 * WordPress EPPP Admin
 *
 * EPPP Admin for EPPP Plugin.
 */
class WP_Easy_Privacy_Policy_Pro_Admin {

    /**
     * EPPP Options
     */
    private $options;

    /**
     * EPPP Admin Constructor
     */
    function __construct() {
        /**
         * Setup Default Options
         */
        $this->set_eppp_default_options();

        /**
         * Add Eppp Options if necessary.
         */
        add_action('after_setup_theme', array($this, 'eppp_options_init'));

        /**
         * Set Eppp Settings Tabs.
         */
        $this->set_settings_page_tabs();

        /**
         * Hook to admin menu and create our menu.
         */
        add_action('admin_menu', array($this, 'admin_menu'));

        /**
         * Register Settings.
         */
        add_action('admin_init', array($this, 'register_settings'));

        /**
         * Plugins Page Customization.
         */
        add_filter('plugin_action_links', array($this, 'action_links'), 10, 4);
        add_filter('plugin_row_meta', array($this, 'plugin_row_meta'), 10, 4);
        add_action('after_plugin_row', array($this, 'after_plugin_row'), 10, 3);
    }

    function after_plugin_row($plugin_file, $plugin_data, $status) {
        if ('Easy Privacy Policy Pro' == $plugin_data['Name']) {
            $icon = '<img src="' . EPPP_URL . 'assets/eppp.png" />';
            echo '<tr><td></td><td>' . $icon . '</td><td><b>Easy Privacy Policy Pro Allows you to create Disclaimer, Terms of Service, Contact and a few other pages.<br /><br /></b></td></tr>';
        }
    }

    function plugin_row_meta($plugin_meta, $plugin_file, $plugin_data, $status) {
        if ('Easy Privacy Policy Pro' == $plugin_data['Name']) {
            $url = admin_url('admin.php?page=manage-eppp&tab=information');
            $plugin_meta[] = 'Fill Your <a href="' . $url . '" title="Enter Your Business Information Here" >Business Information</a> and Create Pages';
        }
        return $plugin_meta;
    }

    function action_links($actions, $plugin_file, $plugin_data, $context) {
        if ('Easy Privacy Policy Pro' == $plugin_data['Name']) {
            if (isset($actions['deactivate'])):
                $actions = $actions;
                $url = admin_url('admin.php?page=manage-eppp');
                $actions['generate'] = '<a href="' . $url . '" title="Generate Pages" >Generate Pages</a>';
            endif;
        }
        return $actions;
    }

    /**
     * Setup Eppp Options Defaults.
     */
    function set_eppp_default_options() {
        $this->options = array(
            'name' => 'BUSINESS NAME',
            'reg_number' => 'REG NUMBER',
            'reg_place' => 'REG PLACE',
            'address' => 'ADDRESS',
            'city' => 'CITY',
            'state' => 'STATE',
            'zip' => 'ZIP',
            'email' => ''
        );
    }

    /**
     * Add Eppp Options if necessary.
     */
    function eppp_options_init() {
        $eppp_options = get_option('eppp_options');
        if (false == $eppp_options)
            update_option('eppp_options', $this->options);
    }

    /**
     * Set Default Tabs
     */
    function set_settings_page_tabs() {
        $this->tabs = array(
            'generator' => 'Page Generator',
            'information' => 'Business Information',
        );
    }

    /**
     * Echo the tabs bar.
     */
    function eppp_settings_tabs() {
        if (isset($_GET['tab'])) :
            $current = $_GET['tab'];
        else:
            $current = 'generator';
        endif;

        $links = array();
        foreach ($this->tabs as $tab => $name) :
            if ($tab == $current) :
                $links[] = '<a class="nav-tab nav-tab-active"
                href="?page=manage-eppp&tab=' .
                        $tab . '" > ' . $name . '</a>';
            else :
                $links[] = '<a class="nav-tab"
                href="?page=manage-eppp&tab=' .
                        $tab . '" >' . $name . '</a>';
            endif;
        endforeach;

        echo '<h2 class="nav-tab-wrapper">';
        foreach ($links as $link):
            echo $link;
        endforeach;
        echo '</h2>';
    }

    /**
     * Register Eppp Settings
     */
    function register_settings() {
        /* Store Eppp Settings in 'eppp_options' option */
        register_setting('eppp_options', 'eppp_options', array($this, 'eppp_options_validate'));
    }

    /**
     * Add Admin Menu
     *
     * Register an admin menu for Eppp Events.
     */
    function admin_menu() {
        $hook_suffix = add_menu_page(
                __('EPPP', 'se'), __('EPPP', 'se'), 'manage_options', 'manage-eppp', array($this, 'render_admin_menu'), EPPP_URL . 'assets/eppp.png', 25
        );
        add_action('admin_print_scripts-' . $hook_suffix, array($this, 'admin_scripts'));
    }

    /**
     * Render Admin Menu
     *
     * Outputs the admin menu
     */
    function render_admin_menu() {
        echo '<div class="wrap">';
        echo '<div id="icon-edit" class="icon32"><br /></div>';
        echo '<h2>' . __('Easy Privacy Policy Pro', 'eppp') . '</h2>';
        $this->eppp_settings_tabs();
        settings_errors();
        echo '<form action="options.php" method="post">';
        if (isset($_GET['tab'])) :
            $tab = $_GET['tab'];
        else:
            $tab = 'generator';
        endif;

        switch ($tab) :
            case 'generator' :
                require EPPP_PATH . 'admin/tab-generator.php';
                break;
            case 'information' :
                require EPPP_PATH . 'admin/tab-information.php';
                break;
        endswitch;

        settings_fields('eppp_options');
        do_settings_sections('manage-eppp');

        echo '</form>';
        echo '</div>';
    }

    /**
     * Eppp Options Validate
     */
    function eppp_options_validate($input) {
        /**
         * Get Current Options.
         */
        $options = get_option('eppp_options');
        $output = $options;

        /**
         * Save Settings.
         */
        if (isset($input['save_settings'])) {
            $output['name'] = sanitize_text_field($input['name']);
            $output['reg_number'] = sanitize_text_field($input['reg_number']);
            $output['reg_place'] = sanitize_text_field($input['reg_place']);
            $output['address'] = sanitize_text_field($input['address']);
            $output['city'] = sanitize_text_field($input['city']);
            $output['state'] = sanitize_text_field($input['state']);
            $output['zip'] = sanitize_text_field($input['zip']);
            $output['email'] = sanitize_email($input['email']);

            $message = 'EPPP Settings Saved';
            $type = 'updated';
        }

        /**
         * Reset Emails Settings.
         */
        if (isset($input['reset_settings'])) {
            $options = $this->options;
            $output = $options;

            $message = 'EPPP Settings Reset';
            $type = 'updated';
        }

        /**
         * Generate Pages
         */
        if (isset($input['generate_pages'])) {
            $pages['pp'] = isset($input['pp']) ? true : false;
            $pages['disclaimer'] = isset($input['disclaimer']) ? true : false;
            $pages['tos'] = isset($input['tos']) ? true : false;
            $pages['contact'] = isset($input['contact']) ? true : false;
            $pages['aaa'] = isset($input['aaa']) ? true : false;

            if ($pages['pp'] || $pages['disclaimer'] || $pages['tos'] || $pages['contact'] || $pages['aaa']) {
                global $wp_eppp;
                $wp_eppp->generator->generate_pages($pages);
                $message = 'Pages Generated';
            } else {
                $message = 'No Pages Generated';
            }
            $type = 'updated';
        }


        add_settings_error(
                'eppp', esc_attr('settings_updated'), __($message), $type
        );
        return $output;
    }

    /**
     * Admin Scripts
     */
    function admin_scripts() {
        wp_register_style('eppp-admin-style', EPPP_URL . 'css/eppp-admin.css');
        wp_enqueue_style('eppp-admin-style');
    }

}

?>
